@@ -5,7 +5,8 @@ name = "input_table"
 # license GPL V3 or greater
 
 from IPython.display import HTML
-from IPython.display import Javascript as JS 
+from IPython.display import Javascript as JS
+import JPSLUtils
 
 import os
 
@@ -34,4 +35,4 @@ def create_input_table():
     function it will add an extra blank cell before the cell in which the table is created. This does
     not occur when doing things in javascript.
     """
-    display(JS('get_table_dim();'))
\ No newline at end of file
+    JPSLUtils.OTJS('get_table_dim();')
\ No newline at end of file
